@@ -231,6 +231,17 @@ def get_bucketName_by_page_id(page_id):
         print(f"get_bucketName_by_page_id : Error : {e}")
         return ""
 
+def get_bucketName_by_productionPage_id(productionPage_id):
+    try:
+        query = "SELECT s3Bucket FROM neuralplatform_account WHERE id = " + \
+            "(SELECT account_id FROM neuralplatform_project WHERE id = " + \
+            "(SELECT project_id FROM neuralplatform_productiondocument WHERE id = " + \
+            f"(SELECT productionDocument_id FROM neuralplatform_productionpage WHERE id = {productionPage_id})));"
+        return run_select(query)[0]['s3Bucket']
+    except Exception as e:
+        print(f"get_bucketName_by_page_id : Error : {e}")
+        return ""
+
 def validate_projectManager(account_code, username, hashed_password):
     accounts = get_n_objects_by_key('account', 1, 'code', account_code)
     if accounts:
@@ -258,9 +269,9 @@ def insert_document(uploadDate, filename, extension, uri, nPages, training, data
 			f'VALUES ("{uploadDate}", "{filename}", "{extension}", "{uri}", {nPages}, {training}, {dataset_id}, {uploadMethod_id}, {project_id});'
 	return run_insert(query)
 
-def insert_productionDocument(uploadDate, filename, extension, uri, nPages, training, dataset_id, uploadMethod_id, project_id):
-	query = f'INSERT INTO neuralplatform_productiondocument(uploadDate, name, extension, uri, nPages, training, dataset_id, uploadMethod_id, project_id) ' + \
-		f'VALUES ("{uploadDate}", "{filename}", "{extension}", "{uri}", {nPages}, {training}, {dataset_id}, {uploadMethod_id}, {project_id});'
+def insert_productionDocument(uploadDate, filename, extension, uri, nPages, training, uploadMethod_id, project_id):
+	query = f'INSERT INTO neuralplatform_productiondocument(uploadDate, name, extension, uri, nPages, training, uploadMethod_id, project_id) ' + \
+		f'VALUES ("{uploadDate}", "{filename}", "{extension}", "{uri}", {nPages}, {training}, {uploadMethod_id}, {project_id});'
 	return run_insert(query)
 
 def insert_request(phase, requestDate, productionDocument_id, project_id):
